Renamed bgpRoutes field in Router class to ribTable.
No functional changes.

Change-Id: I1b5de1b93dc1264adfcd7c4cad9c2a315c1b8992
diff --git a/apps/sdnip/src/test/java/org/onosproject/sdnip/IntentSyncTest.java b/apps/sdnip/src/test/java/org/onosproject/sdnip/IntentSyncTest.java
index 0e6f5a6..5edab7c 100644
--- a/apps/sdnip/src/test/java/org/onosproject/sdnip/IntentSyncTest.java
+++ b/apps/sdnip/src/test/java/org/onosproject/sdnip/IntentSyncTest.java
@@ -291,24 +291,24 @@
         MultiPointToSinglePointIntent intent6 = intentBuilder(
                 routeEntry6.prefix(), "00:00:00:00:00:01",  SW1_ETH1);
 
         // Set up the bgpRoutes field in Router class and routeIntents fields
         // in IntentSynchronizer class
-        InvertedRadixTree<RouteEntry> bgpRoutes =
+        InvertedRadixTree<RouteEntry> ribTable =
                 new ConcurrentInvertedRadixTree<>(
                 new DefaultByteArrayNodeFactory());
-        bgpRoutes.put(RouteEntry.createBinaryString(routeEntry1.prefix()),
-                routeEntry1);
-        bgpRoutes.put(RouteEntry.createBinaryString(routeEntry3.prefix()),
-                routeEntry3);
-        bgpRoutes.put(RouteEntry.createBinaryString(routeEntry4Update.prefix()),
-                routeEntry4Update);
-        bgpRoutes.put(RouteEntry.createBinaryString(routeEntry5.prefix()),
-                routeEntry5);
-        bgpRoutes.put(RouteEntry.createBinaryString(routeEntry6.prefix()),
-                routeEntry6);
-        bgpRoutes.put(RouteEntry.createBinaryString(routeEntry7.prefix()),
-                routeEntry7);
-        TestUtils.setField(router, "bgpRoutes", bgpRoutes);
+        ribTable.put(RouteEntry.createBinaryString(routeEntry1.prefix()),
+                     routeEntry1);
+        ribTable.put(RouteEntry.createBinaryString(routeEntry3.prefix()),
+                     routeEntry3);
+        ribTable.put(RouteEntry.createBinaryString(routeEntry4Update.prefix()),
+                     routeEntry4Update);
+        ribTable.put(RouteEntry.createBinaryString(routeEntry5.prefix()),
+                     routeEntry5);
+        ribTable.put(RouteEntry.createBinaryString(routeEntry6.prefix()),
+                     routeEntry6);
+        ribTable.put(RouteEntry.createBinaryString(routeEntry7.prefix()),
+                     routeEntry7);
+        TestUtils.setField(router, "ribTable", ribTable);
 
         ConcurrentHashMap<Ip4Prefix, MultiPointToSinglePointIntent>
         routeIntents =  new ConcurrentHashMap<>();
@@ -291,24 +291,24 @@
                 routeEntry6.prefix(), "00:00:00:00:00:01",  SW1_ETH1);
 
-        // Set up the bgpRoutes field in Router class and routeIntents fields
+        // Set up the ribTable field in Router class and routeIntents fields
         // in IntentSynchronizer class